@@ -30,6 +30,11 @@ try:
 except ImportError:
 	from urllib import urlencode
 
+try:
+	unicode_ = unicode
+except NameError:
+	unicode_ = str
+
 sys.path.append(os.path.expanduser("~/.tech-parser"))
 
 running_as_daemon = False
@@ -166,7 +171,7 @@ def dump_articles():
 	shuffle(articles)
 	
 	log("Ranking articles...")
-	articles = recommend.find_similiar(articles)
+	articles = recommend.find_similiar(articles, db=config.db)
 	articles.sort(key=lambda x: x[1], reverse=True)
 	
 	log("Dumping data to file: articles_dumped...")
@@ -248,9 +253,40 @@ def serve_static(filename):
 
 @route('/go/<addr:path>')
 def go_to_url(addr):
-	recommend.add_article(addr)
+	recommend.add_article(addr, db=config.db)
 	redirect(addr)
 
+@route('/history')
+@route('/history/<page_number>')
+def show_history(page_number=1):
+	history_page = mylookup.get_template('history.html')
+	q = request.GET.get('q', '')
+	
+	articles = recommend.get_interesting_articles(db=config.db)
+	articles.reverse()
+	
+	try:
+		page_number = int(page_number)
+	except ValueError:
+		page_number = 1
+	
+	if q:
+		qs = q.lower().split()
+		articles = filter(lambda x: has_words(qs, x), articles)
+	
+	all_articles = articles
+	articles = split_into_pages(articles, 30)
+	try:
+		requested_page = articles[page_number-1]
+	except IndexError:
+		requested_page = []
+	
+	return history_page.render(articles=requested_page,
+		num_pages=len(articles),
+		page_num=page_number,
+		q=q,
+		all_articles=all_articles,)
+
 def has_words(qs, article):
 	"""Check if article title contains words:"""
 	
@@ -272,7 +308,8 @@ def prepare_articles(articles, escape=True):
 			article[0]['title'] = article[0]['title'].replace('<', '&lt;')
 			article[0]['title'] = article[0]['title'].replace('>', '&gt;')
 			article[0]['title'] = article[0]['title'].replace('"', '&quot;')
-		article[0]['link'] = urlencode({'': article[0]['link']})[1:]
+		link = unicode_(article[0]['link']).encode('utf-8')
+		article[0]['link'] = urlencode({'': link})[1:]
 		article[0]['summary'] = article[0]['summary'].replace('\n', '<br/>')
 		new_articles.append(article)
 	
@@ -284,11 +321,11 @@ def article_list(page_number=1):
 	"""Show list of articles | Search for articles"""
 	
 	main_page = mylookup.get_template("articles.html")
-	q = request.GET.get('q', '').lower()
+	q = request.GET.get('q', '')
 	
 	try:
 		page_number = int(page_number)
-	except TypeError:
+	except ValueError:
 		page_number = 1
 	
 	try:
@@ -299,7 +336,7 @@ def article_list(page_number=1):
 	
 	articles = filter_articles(articles)
 	if q:
-		qs = q.split()
+		qs = q.lower().split()
 		articles = filter(lambda x: has_words(qs, x), articles)
 	
 	articles = prepare_articles(articles, False)
@@ -310,12 +347,12 @@ def article_list(page_number=1):
 	except IndexError:
 		requested_page = []
 	
-	
 	return main_page.render(articles=requested_page,
 		num_pages=len(articles),
 		page_num=page_number,
 		q=q,
-		all_articles=all_articles)
+		all_articles=all_articles,
+		history=False)
 
 class ParserDaemon(Daemon):
 	def __init__(self):
@@ -374,7 +411,10 @@ Available commands: start|stop|restart|update|run HOST:PORT""")
 	
 	if args.action:
 		if args.action[0] == "run":
-			addr = args.action[1]
+			if len(args.action) == 1:
+				addr = config.host + ":" + config.port
+			else:
+				addr = args.action[1]
 			if not ":" in addr:
 				addr += ":80"
 			elif addr.endswith(":"):
