@@ -13,11 +13,10 @@ def get_articles():
 	
 	posts = []
 	
-	css_paths = ["#haccordion .viewport section .slide .lead-in h3 a",
-		"#feature-hubs .item-list .row .item .title a",
-		"#article-river #tab-content-1 .items li .item-content .title a",
-		"#article-river #tab-content-2 .items li .item-content .title a"
-	]
+	css_paths = ["#article-river #tab-content-1 .items li .item-content .title a",
+		"#article-river #tab-content-2 .items li .item-content .title a",
+		"#haccordion .viewport section .slide .lead-in h3 a",
+		"#feature-hubs .item-list .row .item .title a"]
 	
 	for css_path in css_paths:
 		posts += parser.get_articles(g, css_path, css_path,
